#include "syslogbuf.ih"

SyslogBuf::~SyslogBuf()
{
//    eoi();
}
    
